;;; Gacela, a GNU Guile extension for fast games development
;;; Copyright (C) 2016 by Javier Sancho Fernandez <jsf at jsancho dot org>
;;;
;;; This program is free software: you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation, either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.


(define-module (gacela image)
  #:use-module (gacela scene)
  #:use-module (gacela game)
  #:use-module ((sdl2) #:prefix sdl2:)
  #:use-module ((sdl2 image) #:prefix sdl2:)
  #:use-module ((sdl2 render) #:prefix sdl2:)
  #:use-module ((sdl2 surface) #:prefix sdl2:)
  #:export (bitmap
	    move-xy))

(define (bitmap filename)
  (make-scene
   "bitmap"
   (let ((image (sdl2:load-image filename))
	 (texture #f))
     (let ((a 0))
       (lambda* (#:key (xy '(0 0)))
	 (if (not texture)
	     (set! texture (sdl2:surface->texture %sdl-renderer image)))
	 (sdl2:clear-renderer %sdl-renderer)
	 (sdl2:render-copy %sdl-renderer texture #:dest-rect (sdl2:make-rect (car xy) (cadr xy) (sdl2:surface-width image) (sdl2:surface-height image)))
	 (sdl2:present-renderer %sdl-renderer))))))

(define (move-xy x y scene)
  (define (to-integer n)
    (inexact->exact (round n)))
  (make-scene
   "move-xy"
   (lambda ()
     (let ((xy (list (to-integer (if (procedure? x) (x) x))
		     (to-integer (if (procedure? y) (y) y)))))
       (display-scene scene #:xy xy)))))
